local noise = require("noise");
local tne = noise.to_noise_expression;
local resource_autoplace = require("prototypes.entity.demo-resource-autoplace");

local function resource(resource_parameters, autoplace_parameters)

  return
  {
    type = "resource",
    name = resource_parameters.name,
    icon = "__base__/graphics/icons/" .. resource_parameters.name .. ".png",
    icon_size = 32,
    flags = {"placeable-neutral"},
    order="a-b-"..resource_parameters.order,
    tree_removal_probability = 0.8,
    tree_removal_max_distance = 32 * 32,
    minable =
    {
      mining_particle = resource_parameters.name .. "-particle",
      mining_time = resource_parameters.mining_time,
      result = resource_parameters.name
    },
    collision_box = {{ -0.1, -0.1}, {0.1, 0.1}},
    selection_box = {{ -0.5, -0.5}, {0.5, 0.5}},
    autoplace = resource_autoplace.resource_autoplace_settings{
      name = resource_parameters.name,
      order = resource_parameters.order,
      base_density = autoplace_parameters.base_density,
      has_starting_area_placement = true,
      resource_index = resource_autoplace.get_next_resource_index(),
      regular_rq_factor_multiplier = autoplace_parameters.regular_rq_factor_multiplier;
      starting_rq_factor_multiplier = autoplace_parameters.starting_rq_factor_multiplier;
    },
    stage_counts = {15000, 9500, 5500, 2900, 1300, 400, 150, 80},
    stages =
    {
      sheet =
      {
        filename = "__base__/graphics/entity/" .. resource_parameters.name .. "/" .. resource_parameters.name .. ".png",
        priority = "extra-high",
        size = 64,
        frame_count = 8,
        variation_count = 8,
        hr_version =
        {
          filename = "__base__/graphics/entity/" .. resource_parameters.name .. "/hr-" .. resource_parameters.name .. ".png",
          priority = "extra-high",
          size = 128,
          frame_count = 8,
          variation_count = 8,
          scale = 0.5
        }
      }
    },
    map_color = resource_parameters.map_color
  }
end

data:extend(
{
	{
		type = "noise-layer",
		name = "raw-mana"
	},
	{
		type = "resource",
		name = "raw-mana",
		icon = "__Sorcerio__/graphics/icons/ores/raw-mana.png",
		icon_size = 32,
		flags = {"placeable-neutral"},
		category = "magic-ore",
		order="a-b-a",
		map_color = {r=0.4, g=0.2, b=0.8},
		minable =
		{
		  mining_particle = "iron-ore-particle",
		  mining_time = 1.5,
		  result = "raw-mana"
		},
		collision_box = {{ -0.1, -0.1}, {0.1, 0.1}},
		selection_box = {{ -0.5, -0.5}, {0.5, 0.5}},
		autoplace = resource_autoplace.resource_autoplace_settings{
		  name = "raw-mana",
		  order = "b",
		  base_density = 10,
		  has_starting_area_placement = true,
		  resource_index = 4,
		  regular_rq_factor_multiplier = 1.1;
		  starting_rq_factor_multiplier = 1.5;
		},
		stage_counts = {15000, 9500, 5500, 2900, 1300, 400, 150, 80},	
		stages =
		{
		  sheet =
		  {
			filename = "__base__/graphics/entity/iron-ore/iron-ore.png",
			priority = "extra-high",
			size = 64,
			frame_count = 8,
			variation_count = 8,
			hr_version =
			{
			  filename = "__base__/graphics/entity/iron-ore/hr-iron-ore.png",
			  priority = "extra-high",
			  size = 128,
			  frame_count = 8,
			  variation_count = 8,
			  scale = 0.5
			}
		  }
		},
	},
	{
		type = "noise-layer",
		name = "fire-moss"
	},
	{
		type = "resource",
		name = "fire-moss",
		icon = "__Sorcerio__/graphics/icons/herbs/fire-moss.png",
		icon_size = 32,
		flags = {"placeable-neutral"},
		category = "magic-herb",
		order="a-b-a",
		map_color = {r=0.8, g=0.3, b=0.2},
		minable =
		{
		  mining_particle = "iron-ore-particle",
		  mining_time = 1.5,
		  result = "fire-moss"
		},
		collision_box = {{ -0.1, -0.1}, {0.1, 0.1}},
		selection_box = {{ -0.5, -0.5}, {0.5, 0.5}},
		autoplace = resource_autoplace.resource_autoplace_settings{
		  name = "fire-moss",
		  order = "b",
		  base_density = 10,
		  has_starting_area_placement = true,
		  resource_index = 4,
		  regular_rq_factor_multiplier = 1.1;
		  starting_rq_factor_multiplier = 1.5;
		},
		stage_counts = {15000, 9500, 5500, 2900, 1300, 400, 150, 80},	
		stages =
		{
		  sheet =
		  {
			filename = "__base__/graphics/entity/iron-ore/iron-ore.png",
			priority = "extra-high",
			size = 64,
			frame_count = 8,
			variation_count = 8,
			hr_version =
			{
			  filename = "__base__/graphics/entity/iron-ore/hr-iron-ore.png",
			  priority = "extra-high",
			  size = 128,
			  frame_count = 8,
			  variation_count = 8,
			  scale = 0.5
			}
		  }
		},
	},
}
)
